@@ -7,8 +7,8 @@
 ;; Maintainer: Caramel Hooves <caramel.hooves@protonmail.com>
 ;; Created: March 18, 2023
 ;; Modified: October 7, 2025
-;; Package-Version: 20251015.2150
-;; Package-Revision: 15e6148d0f8c
+;; Package-Version: 20251118.1056
+;; Package-Revision: 0ff615c4b2f1
 ;; Keywords: tools
 ;; Homepage: https://github.com/caramelhooves/teleport.el
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0"))
@@ -269,8 +269,8 @@ OUTPUT-JSON-SYMBOL and call COMPLETION-NOTIFICATION when done."
              output-json-symbol
              process-symbol
              completion-notification
-             cmd)))
-  (symbol-value output-json-symbol))
+             cmd)
+  (symbol-value output-json-symbol)))
 
 (defvar teleport--nodes-async-cache []
   "Cached vector of teleport nodes.")
